Welcome!
========

This is the external, decomposed plugin library for the OpenDaylight ML2
MechanismDriver. This is the backend code which handles communication with
OpenDaylight.

External Resources:
===================

The OpenDaylight homepage:
   http://www.opendaylight.org/

The Launchpad page for openstack/networking-odl:
   https://launchpad.net/networking-odl

File bugs for this project here:
   https://bugs.launchpad.net/networking-odl

The Neutron homepage:
   http://launchpad.net/neutron.
